summaryrefslogtreecommitdiffstats
path: root/chrome/common/chrome_switches.cc
diff options
context:
space:
mode:
authorericroman@google.com <ericroman@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-21 21:49:49 +0000
committerericroman@google.com <ericroman@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-21 21:49:49 +0000
commit27b5ce9bb27f6c4aa60931cea1c3bab2ed3b9e47 (patch)
treebbfa5cdeaa465f9772c23d48ec0ff2d22a631fb2 /chrome/common/chrome_switches.cc
parent209fe9f0fb738e0771f10d68bcc97fce77494a68 (diff)
downloadchromium_src-27b5ce9bb27f6c4aa60931cea1c3bab2ed3b9e47.zip
chromium_src-27b5ce9bb27f6c4aa60931cea1c3bab2ed3b9e47.tar.gz
chromium_src-27b5ce9bb27f6c4aa60931cea1c3bab2ed3b9e47.tar.bz2
Change the default http stack for chrome.exe from winhttp to the new one.
http://code.google.com/p/chromium/issues/detail?id=2645 Review URL: http://codereview.chromium.org/7668 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@3693 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/chrome_switches.cc')
-rw-r--r--chrome/common/chrome_switches.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index 3428318..b751d3b 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -312,8 +312,8 @@ const wchar_t kGearsPluginPathOverride[] = L"gears-plugin-path";
// Switch to load Gears in the renderer process.
const wchar_t kGearsInRenderer[] = L"gears-in-renderer";
-// Enable new HTTP stack.
-const wchar_t kUseNewHttp[] = L"new-http";
+// Enable winhttp HTTP stack.
+const wchar_t kUseWinHttp[] = L"winhttp";
// Enable the fastback page cache.
const wchar_t kEnableFastback[] = L"enable-fastback";